require('dotenv').config();

var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var yesterday = helpers.getYesterday();

var monthAgo = helpers.getMonthAgo();


/**
 *  Generic function to query Mixpanel's api for funnel data given
 * a funnel id. Makes use of mixpanelFunnel function in mixpanel-api-wrapper.
 * The stream returned contains data by day. That is, each event emitted
 * will contain a single days' data.
 *
 * @param {string} mixpanelAPISecret        Mixpanel API secret to access team's data
 * @param {string|integer} id               FunnelID to retrieve results for
 * @returns {stream}                        returns stream of results from Mixpanel API
*/
function updateData(mixpanelAPISecret, id) {
  var options = {
    from_date: helpers.formatDate(monthAgo),
    to_date: helpers.formatDate(yesterday)
  };
  var stream = mixpanel.mixpanelFunnel(mixpanelAPISecret, id, options);
  var transformedStream = helpers.transformStreamFunnel(stream);
  return transformedStream;
}

function updateSuccessData(mixpanelAPISecret) {
  var stream = updateData(mixpanelAPISecret, process.env.updateSuccessID);
  return stream;
}

function updateCancelData(mixpanelAPISecret) {
  var stream = updateData(mixpanelAPISecret, process.env.updateCancelID);
  return stream;
}

module.exports = {
  updateSuccessData: updateSuccessData,
  updateCancelData: updateCancelData
};
