require('dotenv').config();
var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var yesterday = helpers.getYesterday();

var monthAgo = helpers.getMonthAgo();

/**
 *  Function to query Mixpanel's api for funnel data regarding the instance
 * connection funnel. Makes use of mixpanelFunnel function in mixpanel-api-wrapper.
 * The stream returned contains data by day. That is, each event emitted
 * will contain a single days' data.
 *
 * @param {string} mixpanelAPISecret           Mixpanel API secret to access team's data
 * @returns {stream}                returns stream of results from Mixpanel API
*/
function getInstanceData(mixpanelAPISecret) {
  var options = {
    from_date: helpers.formatDate(monthAgo),
    to_date: helpers.formatDate(yesterday)
  };
  var stream = mixpanel.mixpanelFunnel(mixpanelAPISecret, process.env.instanceID, options);
  var transformedStream = helpers.transformStreamFunnel(stream);
  return transformedStream;
}

module.exports = getInstanceData;
